@@ -1,7 +1,7 @@
 """Library for performing speech recognition with the Google Speech Recognition API."""
 
 __author__ = 'Anthony Zhang (Uberi)'
-__version__ = '1.1.1'
+__version__ = '1.1.3'
 __license__ = 'BSD'
 
 import io, os, subprocess, wave
@@ -121,9 +121,9 @@ class Recognizer(AudioSource):
         path = os.path.dirname(os.path.abspath(__file__)) # directory of the current module file, where all the FLAC bundled binaries are stored
         flac_converter = shutil_which("flac") # check for installed version first
         if flac_converter is None: # flac utility is not installed
-            if system == "Windows" and platform.machine() in {"i386", "x86", "x86_64", "AMD64"}: # Windows NT, use the bundled FLAC conversion utility
+            if system == "Windows" and platform.machine() in set("i386", "x86", "x86_64", "AMD64"): # Windows NT, use the bundled FLAC conversion utility
                 flac_converter = os.path.join(path, "flac-win32.exe")
-            elif system == "Linux" and platform.machine() in {"i386", "x86", "x86_64", "AMD64"}:
+            elif system == "Linux" and platform.machine() in set("i386", "x86", "x86_64", "AMD64"):
                 flac_converter = os.path.join(path, "flac-linux-i386")
             else:
                 raise ChildProcessError("FLAC conversion utility not available - consider installing the FLAC command line application")
@@ -156,8 +156,8 @@ class Recognizer(AudioSource):
         frames = collections.deque()
         assert self.pause_threshold >= self.quiet_duration >= 0
         seconds_per_buffer = (source.CHUNK + 0.0) / source.RATE
-        pause_buffer_count = math.ceil(self.pause_threshold / seconds_per_buffer) # number of buffers of quiet audio before the phrase is complete
-        quiet_buffer_count = math.ceil(self.quiet_duration / seconds_per_buffer) # maximum number of buffers of quiet audio to retain before and after
+        pause_buffer_count = int(math.ceil(self.pause_threshold / seconds_per_buffer)) # number of buffers of quiet audio before the phrase is complete
+        quiet_buffer_count = int(math.ceil(self.quiet_duration / seconds_per_buffer)) # maximum number of buffers of quiet audio to retain before and after
         elapsed_time = 0
 
         # store audio input until the phrase starts
@@ -195,9 +195,9 @@ class Recognizer(AudioSource):
                 break
 
          # obtain frame data
-        for i in range(quiet_buffer_count, pause_buffer_count): frames.pop() # remove extra quiet frames at the end
+        for i in range(quiet_buffer_count, pause_count): frames.pop() # remove extra quiet frames at the end
         frame_data = b"".join(list(frames))
-
+        
         return AudioData(source.RATE, self.samples_to_flac(source, frame_data))
 
     def recognize(self, audio_data, show_all = False):
@@ -205,6 +205,7 @@ class Recognizer(AudioSource):
 
         url = "http://www.google.com/speech-api/v2/recognize?client=chromium&lang=%s&key=%s" % (self.language, self.key)
         self.request = Request(url, data = audio_data.data, headers = {"Content-Type": "audio/x-flac; rate=%s" % audio_data.rate})
+        
         # check for invalid key response from the server
         try:
             response = urlopen(self.request)
@@ -245,9 +246,6 @@ class Recognizer(AudioSource):
                 spoken_text.append({"text":prediction["transcript"],"confidence":default_confidence})
         return spoken_text
 
-
-# helper functions
-
 def shutil_which(pgm):
     """
     python2 backport of python3's shutil.which()
@@ -258,7 +256,6 @@ def shutil_which(pgm):
         if os.path.exists(p) and os.access(p, os.X_OK):
             return p
 
-
 if __name__ == "__main__":
     r = Recognizer()
     m = Microphone()
